@@ -1,21 +1,3 @@
-## Copyright 2011-2015 Sebastian Gibb
-## <mail@sebastiangibb.de>
-##
-## This file is part of MALDIquant for R and related languages.
-##
-## MALDIquant is free software: you can redistribute it and/or modify
-## it under the terms of the GNU General Public License as published by
-## the Free Software Foundation, either version 3 of the License, or
-## (at your option) any later version.
-##
-## MALDIquant is distributed in the hope that it will be useful,
-## but WITHOUT ANY WARRANTY; without even the implied warranty of
-## MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
-## GNU General Public License for more details.
-##
-## You should have received a copy of the GNU General Public License
-## along with MALDIquant. If not, see <http://www.gnu.org/licenses/>
-
 ## AbstractMassObject
 if (is.null(getGeneric("as.matrix"))) {
   setGeneric("as.matrix", function(x, ...) standardGeneric("as.matrix"))
@@ -57,6 +39,13 @@ if (is.null(getGeneric("mass"))) {
 if (is.null(getGeneric("mass<-"))) {
   setGeneric("mass<-", function(object, value) standardGeneric("mass<-"))
 }
+# from ProtGenerics (same as mass)
+if (is.null(getGeneric("mz"))) {
+  setGeneric("mz", function(object, ...) standardGeneric("mz"))
+}
+if (is.null(getGeneric("mz<-"))) {
+  setGeneric("mz<-", function(object, value) standardGeneric("mz<-"))
+}
 if (is.null(getGeneric("intensity"))) {
   setGeneric("intensity", function(object, ...) standardGeneric("intensity"))
 }
@@ -143,26 +132,13 @@ if (is.null(getGeneric("totalIonCurrent"))) {
 
 ## MassPeaks
 if (is.null(getGeneric("labelPeaks"))) {
-  setGeneric("labelPeaks",
-             function(object, index, mass, labels, digits=3L, underline=TRUE,
-                      verticalOffset=abs(diff(par("usr")[3:4])) * 0.0125,
-                      absoluteVerticalPos, adj=c(0.5, 0L), cex=0.7,
-                      avoidOverlap=FALSE, arrowLength=0L, arrowLwd=0.5,
-                      arrowCol=1, ...) standardGeneric("labelPeaks"))
+  setGeneric("labelPeaks", function(object, ...) standardGeneric("labelPeaks"))
+}
+if (is.null(getGeneric("monoisotopicPeaks"))) {
+  setGeneric("monoisotopicPeaks",
+             function(object, ...) standardGeneric("monoisotopicPeaks"))
 }
 if (is.null(getGeneric("snr"))) {
   setGeneric("snr", function(object) standardGeneric("snr"))
 }
-if (is.null(getGeneric(".calculateLabelPositions"))) {
-  setGeneric(".calculateLabelPositions",
-             function(object, ...) standardGeneric(".calculateLabelPositions"))
-}
-if (is.null(getGeneric(".testLabelOverlap"))) {
-  setGeneric(".testLabelOverlap",
-             function(object, ...) standardGeneric(".testLabelOverlap"))
-}
-if (is.null(getGeneric(".labelOverlap"))) {
-  setGeneric(".labelOverlap",
-             function(object, ...) standardGeneric(".labelOverlap"))
-}
 ## end of MassPeaks
